@@ -184,40 +184,40 @@ on_expose (GtkWidget* widget, GdkEventExpose* pEvent, gpointer data)
   cairo_set_source_rgba (pContext, 1.0f, 1.0f, 1.0f, fAlpha3);
   cairo_move_to (pContext, (gdouble) iOffsetX, (gdouble) iOffsetY);
   iOffsetX += do_text (pContext,
-           "3 ",
-           24 * PANGO_SCALE,
-           "Bitstream Charter",
-           PANGO_WEIGHT_BOLD,
-           PANGO_STYLE_NORMAL);
+                       "3 ",
+                       24 * PANGO_SCALE,
+                       "Bitstream Charter",
+                       PANGO_WEIGHT_BOLD,
+                       PANGO_STYLE_NORMAL);
   cairo_fill (pContext);
 
   /* draw the 2 */
   cairo_set_source_rgba (pContext, 1.0f, 1.0f, 1.0f, fAlpha2);
   cairo_move_to (pContext, (gdouble) iOffsetX, (gdouble) iOffsetY);
   iOffsetX += do_text (pContext,
-           "2 ",
-           24 * PANGO_SCALE,
-           "Bitstream Charter",
-           PANGO_WEIGHT_BOLD,
-           PANGO_STYLE_NORMAL);
+                       "2 ",
+                       24 * PANGO_SCALE,
+                       "Bitstream Charter",
+                       PANGO_WEIGHT_BOLD,
+                       PANGO_STYLE_NORMAL);
   cairo_fill (pContext);
 
   /* draw the 1 */
   cairo_set_source_rgba (pContext, 1.0f, 1.0f, 1.0f, fAlpha1);
   cairo_move_to (pContext, (gdouble) iOffsetX, (gdouble) iOffsetY);
   iOffsetX += do_text (pContext,
-           "1 ",
-           24 * PANGO_SCALE,
-           "Bitstream Charter",
-           PANGO_WEIGHT_BOLD,
-           PANGO_STYLE_NORMAL);
+                       "1 ",
+                       24 * PANGO_SCALE,
+                       "Bitstream Charter",
+                       PANGO_WEIGHT_BOLD,
+                       PANGO_STYLE_NORMAL);
   cairo_fill (pContext);
 
   /* draw the camera */
   cairo_set_source_surface (pContext,
-          priv->pSurface,
-          (gdouble) iOffsetX,
-          (gdouble) iOffsetY);
+                            priv->pSurface,
+                            (gdouble) iOffsetX,
+                            (gdouble) iOffsetY);
   cairo_paint_with_alpha (pContext, fAlphaClick);
 
   cairo_destroy (pContext);
@@ -240,8 +240,8 @@ create_surface_from_svg (gchar* pcFilename)
   cairo_surface_t*  pSurface   = NULL;
   RsvgHandle*       pSvgHandle = NULL;
   GError*           pError     = NULL;
-  RsvgDimensionData dimension;
   cairo_t*          pContext   = NULL;
+  RsvgDimensionData dimension;
 
   rsvg_init ();
 
@@ -250,6 +250,7 @@ create_surface_from_svg (gchar* pcFilename)
   if (!pSvgHandle)
   {
     g_print ("Could not load file %s!\n", pcFilename);
+    g_error_free(pError);
     return NULL;
   }
 
@@ -294,30 +295,32 @@ static gboolean
 cheese_countdown_cb (gpointer countdown)
 {
   CheeseCountdownPrivate* priv = CHEESE_COUNTDOWN_GET_PRIVATE (countdown);
-  if (priv->iState == STATE_OFF)
+
+  switch (priv->iState)
   {
-    // should just ignore it, testing purposes
-    g_print("Should not happen, unitialized state in countdown handler\n");
-  }
-  else if (priv->iState == STATE_3)
-  {
-    priv->iState = STATE_2;
-  }
-  else if (priv->iState == STATE_2)
-  {
-    priv->iState = STATE_1;
-  }
-  else if (priv->iState == STATE_1)
-  {
-    priv->iState = STATE_SMILE;
-    if (priv->picture_callback != NULL) (priv->picture_callback)(priv->callback_data);
-  }
-  else if (priv->iState == STATE_SMILE)
-  {
-    priv->iState = STATE_OFF;
-    if (priv->hide_callback != NULL) (priv->hide_callback)(priv->callback_data);
-    return FALSE;
+    case STATE_OFF:
+      /* Countdown was cancelled */
+      return FALSE;
+
+    case STATE_3:
+      priv->iState = STATE_2;
+      break;
+
+    case STATE_2:
+      priv->iState = STATE_1;
+      break;
+
+    case STATE_1:
+      priv->iState = STATE_SMILE;
+      if (priv->picture_callback != NULL) (priv->picture_callback)(priv->callback_data);
+      break;
+
+    case STATE_SMILE:
+      priv->iState = STATE_OFF;
+      if (priv->hide_callback != NULL) (priv->hide_callback)(priv->callback_data);
+      return FALSE;
   }
+
   return TRUE;
 }
 
@@ -336,6 +339,13 @@ cheese_countdown_start (CheeseCountdown *countdown, cheese_countdown_cb_t pictur
   g_timeout_add_seconds (1, cheese_countdown_cb, (gpointer) countdown);
 }
 
+void
+cheese_countdown_cancel (CheeseCountdown *countdown)
+{
+  CheeseCountdownPrivate* priv = CHEESE_COUNTDOWN_GET_PRIVATE (countdown);
+  priv->iState = STATE_OFF;
+}
+
 static void
 cheese_countdown_finalize (GObject *object)
 {
